@@ -6,7 +6,7 @@ Initial_mu_var=function(rstat,wholeindex)
   initial_mu_var=list()
   initial_mu_var$upmu[1]=mean(rstat[which(wholeindex==0)])
   initial_mu_var$upmu[2]=mean(rstat[which(wholeindex==1)])
-  initial_mu_var$upvar[1]=var(rstat[which(wholeindex==0)])
-  initial_mu_var$upvar[2]=var(rstat[which(wholeindex==1)])
+  initial_mu_var$upvar[1]=stats::var(rstat[which(wholeindex==0)])
+  initial_mu_var$upvar[2]=stats::var(rstat[which(wholeindex==1)])
   return(initial_mu_var)
 }
