@@ -1,6 +1,6 @@
 #####Transferring large statistical pvalue into testing statistics
 Transfer=function(pvalue)
 {
-  rstat=-(qnorm(pvalue))
+  rstat=-(stats::qnorm(pvalue))
   return(rstat)
 }
